/*
 * Project name: Testing GLCD with PIC16F887
   Embedded-Lab.com, Jan 02, 2012.

 * Description:
     This routine demonstrates how to use MikroC Pro for PIC GLCD library
     routines for displaying texts of various font size.
      * Test configuration:
     MCU:             PIC16F887
     Dev.Board:       UNI-DS6
     Oscillator:      HS, 10.0000 MHz
     Ext. Modules:    GLCD 128x64, KS108/107 controller

*/

// Glcd module connections
char GLCD_DataPort at PORTD;

sbit GLCD_CS1 at RB0_bit;
sbit GLCD_CS2 at RB1_bit;
sbit GLCD_RS  at RB2_bit;
sbit GLCD_RW  at RB3_bit;
sbit GLCD_RST  at RB4_bit;
sbit GLCD_EN at RB5_bit;

sbit GLCD_CS1_Direction at TRISB0_bit;
sbit GLCD_CS2_Direction at TRISB1_bit;
sbit GLCD_RS_Direction  at TRISB2_bit;
sbit GLCD_RW_Direction  at TRISB3_bit;
sbit GLCD_RST_Direction  at TRISB4_bit;
sbit GLCD_EN_Direction at TRISB5_bit;
// End Glcd module connections

void Delay2S(){             // 2 seconds delay function
  Delay_ms(2000);
}

void main() {
  ANSEL  = 0;                                      // Configure AN pins as digital
  ANSELH = 0;
  C1ON_bit = 0;                                    // Disable comparators
  C2ON_bit = 0;
  TRISD = 0x00;
  TRISB = 0x00;
  Glcd_Init();             // Initialize GLCD
  Glcd_Fill(0x00);         // Clear GLCD

  do {
      Glcd_V_Line(0, 63, 64, 1);
      Glcd_H_Line(0, 127, 32, 1);
      Delay2s();
      Glcd_Rectangle(10,5,117,57,1);     // Draw rectangle
      Delay2s();
      Glcd_Circle(64,32, 15, 1);
      Delay2s();
      Glcd_Fill(0xFF);                  // Fill Glcd
      Delay2s();
      Glcd_V_Line(0, 63, 64, 0);
      Glcd_H_Line(0, 127, 32, 0);
      Delay2s();
      Glcd_Rectangle(10,5,117,57,0);     // Draw rectangle
      Delay2s();
      Glcd_Circle(64,32, 15, 0);
      Delay2s();
      Glcd_Fill(0x00);                  // Fill Glcd
      Delay2s();
      Glcd_Box(10,5,117,57,1);
      Delay2s();
      Glcd_Fill(0x00);                  // Fill Glcd
      Delay2s();

      Glcd_Set_Font(Font_Glcd_5x7, 5, 7, 32);
      Glcd_Write_Text("This is Page 0", 10, 0, 1);
      Glcd_Write_Text("This is Page 1", 10, 1, 1);
      Glcd_Write_Text("This is Page 2", 10, 2, 1);
      Glcd_Write_Text("This is Page 3", 10, 3, 1);
      Glcd_Write_Text("This is Page 4", 10, 4, 1);
      Glcd_Write_Text("This is Page 5", 10, 5, 1);
      Glcd_Write_Text("This is Page 6", 10, 6, 1);
      Glcd_Write_Text("This is Page 7", 10, 7, 1);
      Delay2s();
      Glcd_Fill(0x00);         // Clear GLCD
      Glcd_Set_Font(Font_Glcd_Character8x7, 8, 7, 32);
      Glcd_Write_Text("Embedded Lab", 8, 3, 2);   // Write string
      Delay2s();
      Glcd_Fill(0x00);         // Clear GLCD
  } while(1);
}